@@ -1,11 +1,12 @@
 package Test::Data::Riak;
 {
-  $Test::Data::Riak::VERSION = '0.2';
+  $Test::Data::Riak::VERSION = '0.3';
 }
 
 use strict;
 use warnings;
 
+use Try::Tiny;
 use Test::More;
 use Digest::MD5 qw/md5_hex/;
 
@@ -25,28 +26,33 @@ Sub::Exporter::setup_exporter({
 });
 
 sub create_test_bucket_name {
-    'data-riak-test-' . md5_hex(scalar localtime)
+	my $prefix = shift || 'data-riak-test';
+    return $prefix . '-' . md5_hex(scalar localtime)
 }
 
 sub skip_unless_riak {
     my $up = Data::Riak::HTTP->new->ping;
     unless($up) {
-		warn 'Riak did not answer, skipping tests';
-        done_testing;
-        exit;
+        plan skip_all => 'Riak did not answer, skipping tests'
     };
     return $up;
 }
 
 sub remove_test_bucket {
     my $bucket = shift;
-    $bucket->remove_all;
-    Test::More::diag "Removing test bucket so sleeping for a moment to allow riak to eventually be consistent ...";
-    my $keys = $bucket->list_keys;
-    while ( $keys && @$keys ) {
-        sleep(1);
-        $keys = $bucket->list_keys;
-    }
+
+    try {
+        $bucket->remove_all;
+        Test::More::diag "Removing test bucket so sleeping for a moment to allow riak to eventually be consistent ...";
+        my $keys = $bucket->list_keys;
+        while ( $keys && @$keys ) {
+            sleep(1);
+            $keys = $bucket->list_keys;
+        }
+    } catch {
+        is($_->value, "not found\n", "Bucket is now empty");
+        is($_->code, "404", "Calling list_keys on an empty bucket gives a 404");
+    };
 }
 
 
@@ -59,7 +65,7 @@ Test::Data::Riak
 
 =head1 VERSION
 
-version 0.2
+version 0.3
 
 =head1 AUTHOR
 
